@@ -1,9 +1,6 @@
 // debug messages available
 pref("extensions.toggleproxy.debug", false);
 
-// update prefernces on ok button being pressed
-pref("browser.preferences.instantApply", false);
-
 // toggle one default proxy setting = manual
 pref("extensions.toggleproxy.toggleone", 1);
 
